<?php
/**
 * Karen functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * 
 * @package Karen
 * @since Karen 0.1.0
 */

/**
 * Karen only works in WordPress 4.4 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.4-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
}

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Twitter widgets
 */
require get_template_directory() . '/inc/widgets/twitter.php';

/**
 * Recent Posts widgets
 */
require get_template_directory() . '/inc/widgets/recent-posts.php';

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once get_template_directory() . '/inc/tgm-plugin-activation/class-tgm-plugin-activation.php';


if ( ! function_exists( 'karen_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 *
 * Create your own karen_setup() function to override in a child theme.
 *
 * @since Karen 0.1.0
 */
function karen_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Karen, use a find and replace
	 * to change 'karen' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'karen', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 1200, 0, true );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'karen' ),
		'social'  => __( 'Social Links Menu', 'karen' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'image',
		'video',
		'quote',
		'gallery',
		'audio',
	) );

	/*
	 * Enable support for custom logo.
	 *
	 *  @since Karen 0.1.5
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 300,
		'width'       => 300,
		'flex-height' => true,
	) );

}
endif; // karen_setup
add_action( 'after_setup_theme', 'karen_setup' );

/**
 * Sets the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 *
 * @since Karen 0.1.0
 */
function karen_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'karen_content_width', 728 );
}
add_action( 'after_setup_theme', 'karen_content_width', 0 );

/**
 * Registers a widget area.
 *
 * @link https://developer.wordpress.org/reference/functions/register_sidebar/
 *
 * @since Karen 0.1.0
 */
function karen_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'karen' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar.', 'karen' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Content Bottom 1', 'karen' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Appears at the bottom of the content on posts and pages.', 'karen' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Content Bottom 2', 'karen' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Appears at the bottom of the content on posts and pages.', 'karen' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Wide', 'karen' ),
		'id'            => 'footer-widget-wide',
		'description'   => __( 'Appears at the footer displayed full width.', 'karen' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'karen' ),
		'id'            => 'footer-widget-1',
		'description'   => __( 'Appears at the footer displayed as column.', 'karen' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'karen' ),
		'id'            => 'footer-widget-2',
		'description'   => __( 'Appears at the footer displayed as column.', 'karen' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'karen' ),
		'id'            => 'footer-widget-3',
		'description'   => __( 'Appears at the footer displayed as column.', 'karen' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'karen' ),
		'id'            => 'footer-widget-4',
		'description'   => __( 'Appears at the footer displayed as column.', 'karen' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

}
add_action( 'widgets_init', 'karen_widgets_init' );

if ( ! function_exists( 'karen_fonts_url' ) ) :
/**
 * Register Google fonts for Karen.
 *
 * Create your own karen_fonts_url() function to override in a child theme.
 *
 * @since Karen 0.1.0
 *
 * @return string Google fonts URL for the theme.
 */
function karen_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/* translators: If there are characters in your language that are not supported by Copse, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Copse font: on or off', 'karen' ) ) {
		$fonts[] = 'Copse';
	}

	/* translators: If there are characters in your language that are not supported by Quattrocento Sans, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Quattrocento Sans font: on or off', 'karen' ) ) {
		$fonts[] = 'Quattrocento Sans:400,700,400italic,700italic';
	}

	/* translators: If there are characters in your language that are not supported by Inconsolata, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Inconsolata font: on or off', 'karen' ) ) {
		$fonts[] = 'Inconsolata:400';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}
endif;

/**
 * Handles JavaScript detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since Karen 0.1.0
 */
function karen_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'karen_javascript_detection', 0 );

/**
 * Enqueues scripts and styles.
 *
 * @since Karen 0.1.0
 */
function karen_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'karen-fonts', karen_fonts_url(), array(), null );

	// Add Genericons, used in the main stylesheet.
	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/genericons/genericons.css', array(), '3.4.1' );

	// Theme stylesheet.
	wp_enqueue_style( 'karen-style', get_stylesheet_uri() );

	// Load the Internet Explorer specific stylesheet.
	wp_enqueue_style( 'karen-ie', get_template_directory_uri() . '/css/ie.css', array( 'karen-style' ), '20151128' );
	wp_style_add_data( 'karen-ie', 'conditional', 'lt IE 10' );

	// Load the Internet Explorer 8 specific stylesheet.
	wp_enqueue_style( 'karen-ie8', get_template_directory_uri() . '/css/ie8.css', array( 'karen-style' ), '20151128' );
	wp_style_add_data( 'karen-ie8', 'conditional', 'lt IE 9' );

	// Load the Internet Explorer 7 specific stylesheet.
	wp_enqueue_style( 'karen-ie7', get_template_directory_uri() . '/css/ie7.css', array( 'karen-style' ), '20151128' );
	wp_style_add_data( 'karen-ie7', 'conditional', 'lt IE 8' );

	// Load the html5 shiv.
	wp_enqueue_script( 'html5', get_template_directory_uri() . '/js/html5.js', array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'karen-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151128', true );

	// Object fit polyfill
	wp_enqueue_script( 'ofi', get_template_directory_uri() . '/js/ofi.min.js', array(), '20151128', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'karen-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20151128' );
	}

	wp_enqueue_script( 'karen-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '20151128', true );

	wp_localize_script( 'karen-script', 'karenScreenReaderText', array(
		'expand'   => __( 'expand child menu', 'karen' ),
		'collapse' => __( 'collapse child menu', 'karen' ),
	) );
}
add_action( 'wp_enqueue_scripts', 'karen_scripts' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @since Karen 0.1.0
 *
 * @param array $classes Classes for the body element.
 * @return array (Maybe) filtered body classes.
 */
function karen_body_classes( $classes ) {
	// Adds a class of custom-background-image to sites with a custom background image.
	if ( get_background_image() ) {
		$classes[] = 'custom-background-image';
	}

	// Adds a class of group-blog to sites with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of left-sidebar when left sidebar in customizer is checked.
	if ( 'left-sidebar' == get_theme_mod('layout_sidebar') ) {
		$classes[] = 'left-sidebar';
	}

	// Adds a class of no-sidebar to sites without active sidebar.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		//$classes[] = 'no-sidebar';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'karen_body_classes' );

/**
 * Converts a HEX value to RGB.
 *
 * @since Karen 0.1.0
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function karen_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ).substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ).substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ).substr( $color, 2, 1 ) );
	} else if ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array( 'red' => $r, 'green' => $g, 'blue' => $b );
}

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for content images
 *
 * @since Karen 0.1.0
 *
 * @param string $sizes A source size value for use in a 'sizes' attribute.
 * @param array  $size  Image size. Accepts an array of width and height
 *                      values in pixels (in that order).
 * @return string A source size value for use in a content image 'sizes' attribute.
 */
function karen_content_image_sizes_attr( $sizes, $size ) {
	$width = $size[0];

	840 <= $width && $sizes = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 1362px) 62vw, 840px';

	if ( 'page' === get_post_type() ) {
		840 > $width && $sizes = '(max-width: ' . $width . 'px) 85vw, ' . $width . 'px';
	} else {
		840 > $width && 600 <= $width && $sizes = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 984px) 61vw, (max-width: 1362px) 45vw, 600px';
		600 > $width && $sizes = '(max-width: ' . $width . 'px) 85vw, ' . $width . 'px';
	}

	return $sizes;
}
add_filter( 'wp_calculate_image_sizes', 'karen_content_image_sizes_attr', 10 , 2 );

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for post thumbnails
 *
 * @since Karen 0.1.0
 *
 * @param array $attr Attributes for the image markup.
 * @param int   $attachment Image attachment ID.
 * @param array $size Registered image size or flat array of height and width dimensions.
 * @return string A source size value for use in a post thumbnail 'sizes' attribute.
 */
function karen_post_thumbnail_sizes_attr( $attr, $attachment, $size ) {
	if ( 'post-thumbnail' === $size ) {
		is_active_sidebar( 'sidebar-1' ) && $attr['sizes'] = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 984px) 60vw, (max-width: 1362px) 62vw, 840px';
		! is_active_sidebar( 'sidebar-1' ) && $attr['sizes'] = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 1362px) 88vw, 1200px';
	}
	return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'karen_post_thumbnail_sizes_attr', 10 , 3 );

/**
 * Exclude posts that shown on featured posts from the homepage
 *
 * @since Karen 0.1.0
 *
 * @param WP_Query	$query Current global query.
 */
function karen_exclude_featured_pre_get_posts($query){
	if (	$query->is_home() && 
			$query->is_main_query() && 
			get_theme_mod('featured_posts_on') ) {

		$posts_on_feature = new WP_Query( 	array(
			'tag_slug__in' => get_theme_mod('featured_posts_tags'),
			'posts_per_page' => get_theme_mod('featured_posts_number'),
		) );

		while ( $posts_on_feature->have_posts() ) {
			$current_post = $posts_on_feature->next_post();
			$exclude[] = $current_post->ID;
		}

		$query->set( 'post__not_in', $exclude );

	}

	return $query;
}
add_action('pre_get_posts', 'karen_exclude_featured_pre_get_posts');


/**
 * Setup a font controls & settings for Easy Google Fonts plugin (if installed)
 *
 * @since Karen 0.1.0
 *
 * @param array $options Default control list by the plugin.
 * @return array Modified $options parameter to applied in filter 'tt_font_get_option_parameters'.
 */
function karen_easy_google_fonts($options) {

	// Just replace all the plugin default font control

	unset(  $options['tt_default_body'],
			$options['tt_default_heading_2'],
			$options['tt_default_heading_3'],
			$options['tt_default_heading_4'],
			$options['tt_default_heading_5'],
			$options['tt_default_heading_6'],
			$options['tt_default_heading_1']
		);

	$new_options = array(
		
		'karen_default_body' => array(
			'name'        => 'karen_default_body',
			'title'       => __( 'Body & Paragraphs', 'karen' ),
			'description' => __( "Please select a font for the theme's body and paragraph text", 'karen' ),
			'properties'  => array( 'selector' => apply_filters( 'karen_default_body', 'body, button, input, select, textarea, blockquote cite, .entry-footer' ) ),
		),

		'karen_default_heading' => array(
			'name'        => 'karen_default_heading',
			'title'       => __( 'Headings', 'karen' ),
			'description' => __( "Please select a font for the theme's headings styles", 'karen' ),
			'properties'  => array( 'selector' => apply_filters( 'karen_default_heading', 'h1, h2, h3, h4, h5, h6, .widget .widget-title, .entry-footer .cat-links, .site-featured-posts .slider-nav .featured-title, .site-header .site-title, .site-footer .site-title, button, input[type="button"], input[type="reset"], input[type="submit"], .comment-form label, blockquote' ) ),
		),

		'karen_default_menu' => array(
			'name'        => 'karen_default_menu',
			'title'       => __( 'Menu', 'karen' ),
			'description' => __( "Please select a font for the theme's menu styles", 'karen' ),
			'properties'  => array( 'selector' => apply_filters( 'karen_default_heading', '.main-navigation' ) ),
		),

		'karen_default_entry_title' => array(
			'name'        => 'karen_default_entry_title',
			'title'       => __( 'Entry Title', 'karen' ),
			'description' => __( "Please select a font for the theme's Entry title styles", 'karen' ),
			'properties'  => array( 'selector' => apply_filters( 'karen_default_heading', '.entry-title, .post-navigation .post-title' ) ),
		),

	);

	return array_merge( $options, $new_options);
}
add_filter( 'tt_font_get_option_parameters', 'karen_easy_google_fonts', 10 , 1 );

/**
 * Setup for installation of plugins required and recommended by the theme
 *
 * @since Karen 0.1.0
 *
 */
function karen_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		// The theme required oAuth Twitter Feed for Developers plugin for the twitter widget.
		array(
			'name'               => __( 'oAuth Twitter Feed for Developers', 'karen' ), 
			'slug'               => 'oauth-twitter-feed-for-developers', 
			'required'           => false, 
		),

		// The theme recommend the Easy Google Fonts selection plugin.
		array(
			'name'               => __( 'Easy Google Fonts', 'karen' ), 
			'slug'               => 'easy-google-fonts', 
			'required'           => false, 
		),

		// The theme recommend the Optin forms.
		array(
			'name'               => __( 'Optin Forms', 'karen'), 
			'slug'               => 'optin-forms', 
			'required'           => false, 
		),

	);

	$config = array(
		'id'           => 'karen',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}
add_action( 'tgmpa_register', 'karen_register_required_plugins' );