<?php
/**
 * Karen Customizer functionality
 *
 * 
 * @package Karen
 * @since Karen 0.1.0
 */

/**
 * Sets up the WordPress core custom header and custom background features.
 *
 * @since Karen 0.1.0
 *
 * @see karen_header_style()
 */
function karen_custom_header_and_background() {
	$color_scheme             = karen_get_color_scheme();
	$default_background_color = trim( $color_scheme[0], '#' );
	$default_text_color       = trim( $color_scheme[3], '#' );

	/**
	 * Filter the arguments used when adding 'custom-background' support in Karen.
	 *
	 * @since Karen 0.1.0
	 *
	 * @param array $args {
	 *     An array of custom-background support arguments.
	 *
	 *     @type string $default-color Default color of the background.
	 * }
	 */
	add_theme_support( 'custom-background', apply_filters( 'karen_custom_background_args', array(
		'default-color' => $default_background_color,
		'wp-head-callback' => 'karen_background_style',
	) ) );

	/**
	 * Filter the arguments used when adding 'custom-header' support in Karen.
	 *
	 * @since Karen 0.1.0
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type string $default-text-color Default color of the header text.
	 *     @type int      $width            Width in pixels of the custom header image. Default 1200.
	 *     @type int      $height           Height in pixels of the custom header image. Default 280.
	 *     @type bool     $flex-height      Whether to allow flexible-height header images. Default true.
	 *     @type callable $wp-head-callback Callback function used to style the header image and text
	 *                                      displayed on the blog.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'karen_custom_header_args', array(
		'default-text-color'     => $default_text_color,
		'width'                  => 1200,
		'height'                 => 280,
		'flex-height'            => true,
		'wp-head-callback'       => 'karen_header_style',
	) ) );
}
add_action( 'after_setup_theme', 'karen_custom_header_and_background' );


if ( ! function_exists( 'karen_background_style' ) ) :
/**
 * Styles the background image on the site.
 *
 * Create your own karen_background_style() function to override in a child theme.
 *
 * @since Karen 0.1.0
 *
 * @see karen_custom_header_and_background().
 */
function karen_background_style() {
	$background = get_background_image();

	$style = '';
 
	if ( $background ) {
		$image = " background-image: url('$background');";
 
		$repeat = get_theme_mod( 'background_repeat', 'repeat' );
		if ( ! in_array( $repeat, array( 'no-repeat', 'repeat-x', 'repeat-y', 'repeat' ) ) )
			$repeat = 'repeat';
		$repeat = " background-repeat: $repeat;";
 
		$position = get_theme_mod( 'background_position_x', 'left' );
		if ( ! in_array( $position, array( 'center', 'right', 'left' ) ) )
			$position = 'left';
		$position = " background-position: top $position;";
 
		$attachment = get_theme_mod( 'background_attachment', 'scroll' );
		if ( ! in_array( $attachment, array( 'fixed', 'scroll' ) ) )
			$attachment = 'scroll';
		$attachment = " background-attachment: $attachment;";
 
		$style .= $image . $repeat . $position . $attachment;
	}
?>
<style type="text/css">
	body.custom-background { <?php echo esc_attr( trim( $style ) ); ?> }
</style>
<?php
}
endif; // karen_background_style


if ( ! function_exists( 'karen_header_style' ) ) :
/**
 * Styles the header text displayed on the site.
 *
 * Create your own karen_header_style() function to override in a child theme.
 *
 * @since Karen 0.1.0
 *
 * @see karen_custom_header_and_background().
 */
function karen_header_style() {
	// If the header text option is untouched, let's bail.
	if ( display_header_text() ) {
		return;
	}

	// If the header text has been hidden.
	?>
	<style type="text/css" id="karen-header-css">
		.site-branding {
			margin: 0 auto 0 0;
		}

		.site-branding .site-title,
		.site-description {
			clip: rect(1px, 1px, 1px, 1px);
			position: absolute;
		}
	</style>
	<?php
}
endif; // karen_header_style

/**
 * Adds postMessage support for site title and description for the Customizer.
 *
 * @since Karen 0.1.0
 *
 * @param WP_Customize_Manager $wp_customize The Customizer object.
 */
function karen_customize_register( $wp_customize ) {
	$color_scheme = karen_get_color_scheme();

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	// Add color scheme setting and control.
	$wp_customize->add_setting( 'color_scheme', array(
		'default'           => 'default',
		'sanitize_callback' => 'karen_sanitize_color_scheme',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( 'color_scheme', array(
		'label'    => __( 'Base Color Scheme', 'karen' ),
		'section'  => 'colors',
		'type'     => 'select',
		'choices'  => karen_get_color_scheme_choices(),
		'priority' => 1,
	) );

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );
	$wp_customize->remove_setting('background_color');
	$wp_customize->remove_control('background_color');

	// Add link color setting and control.
	$wp_customize->add_setting( 'base_background_color', array(
		'default'           => $color_scheme[0],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'base_background_color', array(
		'label'       => __( 'Background Color', 'karen' ),
		'section'     => 'colors',
	) ) );

	// Add link color setting and control.
	$wp_customize->add_setting( 'link_color', array(
		'default'           => $color_scheme[1],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
		'label'       => __( 'Link Color', 'karen' ),
		'section'     => 'colors',
	) ) );

	// Add main text color setting and control.
	$wp_customize->add_setting( 'main_text_color', array(
		'default'           => $color_scheme[2],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_text_color', array(
		'label'       => __( 'Main Text Color', 'karen' ),
		'section'     => 'colors',
	) ) );

	// Add secondary text color setting and control.
	$wp_customize->add_setting( 'secondary_text_color', array(
		'default'           => $color_scheme[3],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_text_color', array(
		'label'       => __( 'Secondary Text Color', 'karen' ),
		'section'     => 'colors',
	) ) );



	// Add page background color setting and control.
	$wp_customize->add_setting( 'content_background_color', array(
		'default'           => $color_scheme[4],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'content_background_color', array(
		'label'       => __( 'Content Background Color', 'karen' ),
		'section'     => 'colors',
	) ) );


	// Add link color setting and control.
	$wp_customize->add_setting( 'content_link_color', array(
		'default'           => $color_scheme[5],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'content_link_color', array(
		'label'       => __( 'Content Link Color', 'karen' ),
		'section'     => 'colors',
	) ) );

	// Add main text color setting and control.
	$wp_customize->add_setting( 'content_main_text_color', array(
		'default'           => $color_scheme[6],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'content_main_text_color', array(
		'label'       => __( 'Content Main Text Color', 'karen' ),
		'section'     => 'colors',
	) ) );

	// Add secondary text color setting and control.
	$wp_customize->add_setting( 'content_secondary_text_color', array(
		'default'           => $color_scheme[7],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'content_secondary_text_color', array(
		'label'       => __( 'Content Secondary Text Color', 'karen' ),
		'section'     => 'colors',
	) ) );

	/* 
	 * Section Featured Posts
	 *
	 * All the featured posts setting, most of the setting used on featured-posts.php
	 */
	$wp_customize->add_section('featured_posts', array (
		'title'		  => __('Featured Posts', 'karen'),
		/*'priority'	  => 30,*/
	) );

	// Add activate featured posts' section setting and control.
	$wp_customize->add_setting( 'featured_posts_on', array(
		'default'	=> false,
		'sanitize_callback' => 'karen_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'featured_posts_on', array(
		'setting'	=> 'featured_posts_on',
		'label'		=> __('Activate featured posts', 'karen'),
		'type'		=> 'checkbox',
		'section'	=> 'featured_posts'
	) );

	// Add featured posts tags
	$wp_customize->add_setting('featured_posts_tags', array(
		'default'	=> 'featured',
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control('featured_posts_tags', array(
		'setting'		=> 'featured_posts_tags',
		'label'			=> __('Tags', 'karen'),
		'type'			=> 'text',
		'section'		=> 'featured_posts',
	) );

	// Add featured posts number
	$wp_customize->add_setting('featured_posts_number', array(
		'default'	=> 5,
		'sanitize_callback' => 'karen_sanitize_number_absint',
	) );

	$wp_customize->add_control('featured_posts_number', array(
		'setting'		=> 'featured_posts_number',
		'label'			=> __('Maximum number of posts', 'karen'),
		'type'			=> 'select',
		'choices'		=> array( 1 => 1, 2 => 2 , 3 => 3, 4 => 4, 5 => 5, 6 => 6, 7 => 7, 8 => 8, 9 => 9, 10 => 10),
		'section'		=> 'featured_posts',
	) );

	// Add featured posts type setting
	$wp_customize->add_setting('featured_posts_type', array(
		'default'	=> 'fade',
		'sanitize_callback' => 'karen_sanitize_featured_posts_type',
	) );

	$wp_customize->add_control('featured_posts_type', array(
		'setting'		=> 'featured_posts_type',
		'label'			=> __('Slider type', 'karen'),
		'type'			=> 'radio',
		'choices'		=> array( 'fade' => __('Fade in/out', 'karen'), 'slide-horizontal' => __('Slide horizontal', 'karen')),
		'section'		=> 'featured_posts',
	) );

	// Hiding the featured posts on homepage.
	$wp_customize->add_setting( 'featured_posts_hide', array(
		'default'	=> true,
		'sanitize_callback' => 'karen_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'featured_posts_hide', array(
		'setting'	=> 'featured_posts_hide',
		'label'		=> __('Prevent posts that featured shown on recent posts section', 'karen'),
		'type'		=> 'checkbox',
		'section'	=> 'featured_posts'
	) );

	/* 
	 * Section Layout
	 *
	 * All the layout setting
	 */
	$wp_customize->add_section('layout', array (
		'title'		  => __('Layout', 'karen'),
		/*'priority'	  => 30,*/
	) );

	$wp_customize->add_setting( 'layout_sidebar', array(
		'default'	=> 'right-sidebar',
		'transport' => 'postMessage',
		'sanitize_callback' => 'karen_sanitize_layout_sidebar',
	) );
	$wp_customize->add_control('layout_sidebar', array(
		'setting'	  => 'layout_sidebar',
		'label'		  => __('Sidebar', 'karen'),
		'description' => __('The position of sidebar.', 'karen'),
		'type'		  => 'radio',
		'choices'	  => array( 
			'right-sidebar' => __('Right Sidebar', 'karen'),
			'left-sidebar' => __('Left Sidebar', 'karen')
		),
		'section'		=> 'layout',
	) );

	$wp_customize->add_setting( 'overlay_image_tag', array(
		'default'	=> '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control('overlay_image_tag', array(
		'setting'		=> 'overlay_image_post',
		'label'			=> __("Overlay image post's tag", 'karen'),
		'description'  => __('Tag the posts with this term to display posts with overlay image.', 'karen'),
		'type'			=> 'text',
		'section'		=> 'layout',
	) );

	/* 
	 * Section Footer
	 *
	 * All the footer setting
	 */
	$wp_customize->add_section('footer_setting', array (
		'title'		  => __('Footer Setting', 'karen'),
	) );

	$wp_customize->add_setting( 'footer_credit', array(
		'default'	=> '',
		'sanitize_callback' => 'karen_sanitize_footer_credit',
		'transport' => 'postMessage',
	) );
	$wp_customize->add_control('footer_credit', array(
		'setting'		=> 'footer_credit',
		'label'			=> __('Footer credit text', 'karen'),
		'type'			=> 'textarea',
		'section'		=> 'footer_setting',
	) );


}
add_action( 'customize_register', 'karen_customize_register', 11 );

/**
 * Sanitize the option for layout sidebar.
 *
 * @since Karen 0.1.6
 *
 * @return any of the option available.
 */
function karen_sanitize_layout_sidebar ( $value ) {
	return in_array( $value, array( 'right-sidebar', 'left-sidebar' ) ) ? $value : 'right-sidebar';
}

/**
 * Sanitize the option for featured posts type.
 *
 * @since Karen 0.1.6
 *
 * @return any of the option available.
 */
function karen_sanitize_featured_posts_type ( $value ) {
	return in_array( $value, array( 'fade', 'slide-horizontal' ) ) ? $value : 'fade';
}

/**
 * Allowed html tags for footer credit.
 *
 * @since Karen 0.1.0
 *
 * @return HTML string sanitized with wpkses.
 */
function karen_sanitize_footer_credit($value) {
	$allowed_tags = array(
						'a' => array(
							'href' => array(),
							'title' => array(),
							'rel' => array(),
						),
						'br' => array(),
						'em' => array(),
						'strong' => array(),
						);
	return wp_kses( $value, $allowed_tags );
}

/**
 * Checkbox sanitization callback.
 * 
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @since Karen 0.1.0
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function karen_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

/**
 * Number sanitization callback.
 *
 * - Sanitization: number_absint
 * - Control: number
 * 
 * Sanitization callback for 'number' type text inputs. This callback sanitizes `$number`
 * as an absolute integer (whole number, zero or greater).
 * 
 * NOTE: absint() can be passed directly as `$wp_customize->add_setting()` 'sanitize_callback'.
 * It is wrapped in a callback here merely for example purposes.
 * 
 * @see absint() https://developer.wordpress.org/reference/functions/absint/
 *
 * @param int                  $number  Number to sanitize.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return int Sanitized number; otherwise, the setting default.
 */
function karen_sanitize_number_absint( $number, $setting ) {
	// Ensure $number is an absolute integer (whole number, zero or greater).
	$number = absint( $number );
	
	// If the input is an absolute integer, return it; otherwise, return the default
	return ( $number ? $number : $setting->default );
}

/**
 * Image sanitization callback.
 *
 * Checks the image's file extension and mime type against a whitelist. If they're allowed,
 * send back the filename, otherwise, return the setting default.
 *
 * - Sanitization: image file extension
 * - Control: text, WP_Customize_Image_Control
 * 
 * @see wp_check_filetype() https://developer.wordpress.org/reference/functions/wp_check_filetype/
 *
 * @param string               $image   Image filename.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return string The image filename if the extension is allowed; otherwise, the setting default.
 */
function karen_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}

/**
 * Registers color schemes for Karen.
 *
 * Can be filtered with {@see 'karen_color_schemes'}.
 *
 * The order of colors in a colors array:
 * 1. Main Background Color.
 * 2. Page Background Color.
 * 3. Link Color.
 * 4. Main Text Color.
 * 5. Secondary Text Color.
 *
 * @since Karen 0.1.0
 *
 * @return array An associative array of color scheme options.
 */
function karen_get_color_schemes() {
	/**
	 * Filter the color schemes registered for use with Karen.
	 *
	 * The default schemes include 'default', 'dark', 'gray', 'red', and 'yellow'.
	 *
	 * @since Karen 0.1.0
	 *
	 * @param array $schemes {
	 *     Associative array of color schemes data.
	 *
	 *     @type array $slug {
	 *         Associative array of information for setting up the color scheme.
	 *
	 *         @type string $label  Color scheme label.
	 *         @type array  $colors HEX codes for default colors prepended with a hash symbol ('#').
	 *                              Colors are defined in the following order: Main background, page
	 *                              background, link, main text, secondary text.
	 *     }
	 * }
	 */
	return apply_filters( 'karen_color_schemes', array(
		'default' => array(
			'label'  => __( 'Default', 'karen' ),
			'colors' => array(
				'#f7f7f7',
				'#dd3333',
				'#212121',
				'#686868',
				'#ffffff',
				'#dd4444',
				'#1a1a1a',
				'#686868',
			),
		),
		'dark' => array(
			'label'  => __( 'Dark', 'karen' ),
			'colors' => array(
				'#262626',
				'#9adffd',
				'#e5e5e5',
				'#c1c1c1',
				'#1a1a1a',
				'#9adffd',
				'#e5e5e5',
				'#c1c1c1',
			),
		),
		'gray' => array(
			'label'  => __( 'Gray', 'karen' ),
			'colors' => array(
				'#616a73',
				'#c7c7c7',
				'#f2f2f2',
				'#f2f2f2',
				'#4d545c',
				'#c7c7c7',
				'#f2f2f2',
				'#f2f2f2',
			),
		),
		'yellow' => array(
			'label'  => __( 'Yellow', 'karen' ),
			'colors' => array(
				'#3b3721',
				'#ffef8e',
				'#fff0ad',
				'#fff0ad',
				'#ffef8e',
				'#774e24',
				'#3b3721',
				'#5b4d3e',
			),
		),
		'red' => array(
			'label'  => __( 'Red', 'karen' ),
			'colors' => array(
				'#ffffff',
				'#640c1f',
				'#1a1a1a',
				'#686868',
				'#ff675f',
				'#640c1f',
				'#402b30',
				'#402b30',
			),
		),
		'black_yellow' => array(
			'label'  => __( 'Black + Yellow', 'karen' ),
			'colors' => array(
				'#ffef8e',
				'#774e24',
				'#3b3721',
				'#5b4d3e',
				'#1a1a1a',
				'#ffffff',
				'#efefef',
				'#686868',
			),
		),
		'dark_light' => array(
			'label'  => __( 'Dark-Light', 'karen' ),
			'colors' => array(
				'#1a1a1a',
				'#ffffff',
				'#efefef',
				'#686868',
				'#ffffff',
				'#007acc',
				'#1a1a1a',
				'#686868',
			),
		),
	) );
}

if ( ! function_exists( 'karen_get_color_scheme' ) ) :
/**
 * Retrieves the current Karen color scheme.
 *
 * Create your own karen_get_color_scheme() function to override in a child theme.
 *
 * @since Karen 0.1.0
 *
 * @return array An associative array of either the current or default color scheme HEX values.
 */
function karen_get_color_scheme() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );
	$color_schemes       = karen_get_color_schemes();

	if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {
		return $color_schemes[ $color_scheme_option ]['colors'];
	}

	return $color_schemes['default']['colors'];
}
endif; // karen_get_color_scheme

if ( ! function_exists( 'karen_get_color_scheme_choices' ) ) :
/**
 * Retrieves an array of color scheme choices registered for Karen.
 *
 * Create your own karen_get_color_scheme_choices() function to override
 * in a child theme.
 *
 * @since Karen 0.1.0
 *
 * @return array Array of color schemes.
 */
function karen_get_color_scheme_choices() {
	$color_schemes                = karen_get_color_schemes();
	$color_scheme_control_options = array();

	foreach ( $color_schemes as $color_scheme => $value ) {
		$color_scheme_control_options[ $color_scheme ] = $value['label'];
	}

	return $color_scheme_control_options;
}
endif; // karen_get_color_scheme_choices


if ( ! function_exists( 'karen_sanitize_color_scheme' ) ) :
/**
 * Handles sanitization for Karen color schemes.
 *
 * Create your own karen_sanitize_color_scheme() function to override
 * in a child theme.
 *
 * @since Karen 0.1.0
 *
 * @param string $value Color scheme name value.
 * @return string Color scheme name.
 */
function karen_sanitize_color_scheme( $value ) {
	$color_schemes = karen_get_color_scheme_choices();

	if ( ! array_key_exists( $value, $color_schemes ) ) {
		return 'default';
	}

	return $value;
}
endif; // karen_sanitize_color_scheme

/**
 * Enqueues front-end CSS for color scheme.
 *
 * @since Karen 0.1.0
 *
 * @see wp_add_inline_style()
 */
function karen_color_scheme_css() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );

	// Don't do anything if the default color scheme is selected.
	if ( 'default' === $color_scheme_option ) {
		return;
	}

	$color_scheme = karen_get_color_scheme();

	// Convert main text hex color to rgba.
	$color_textcolor_rgb = karen_hex2rgb( $color_scheme[2] );
	$color_content_textcolor_rgb = karen_hex2rgb( $color_scheme[6] );

	// If the rgba values are empty return early.
	if ( empty( $color_textcolor_rgb ) ) {
		return;
	}

	// If we get this far, we have a custom color scheme.
	$colors = array(
		'base_background_color'         => $color_scheme[0],
		'link_color'                    => $color_scheme[1],
		'main_text_color'               => $color_scheme[2],
		'secondary_text_color'          => $color_scheme[3],
		'border_color'                  => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.2)', $color_textcolor_rgb ),
		'content_background_color'      => $color_scheme[4],
		'content_link_color'            => $color_scheme[5],
		'content_main_text_color'       => $color_scheme[6],
		'content_secondary_text_color'  => $color_scheme[7],
		'content_border_color'          => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.2)', $color_content_textcolor_rgb ),

	);

	$color_scheme_css = esc_html( karen_get_color_scheme_css( $colors ) );

	wp_add_inline_style( 'karen-style', $color_scheme_css );
}
add_action( 'wp_enqueue_scripts', 'karen_color_scheme_css' );

/**
 * Binds the JS listener to make Customizer color_scheme control.
 *
 * Passes color scheme data as colorScheme global.
 *
 * @since Karen 0.1.0
 */
function karen_customize_control_js() {
	wp_enqueue_script( 'karen-color-scheme-control', get_template_directory_uri() . '/js/color-scheme-control.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '20151128', true );
	wp_localize_script( 'karen-color-scheme-control', 'colorScheme', karen_get_color_schemes() );
}
add_action( 'customize_controls_enqueue_scripts', 'karen_customize_control_js' );

/**
 * Binds JS handlers to make the Customizer preview reload changes asynchronously.
 *
 * @since Karen 0.1.0
 */
function karen_customize_preview_js() {
	wp_enqueue_script( 'karen-customize-preview', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '20151128', true );
}
add_action( 'customize_preview_init', 'karen_customize_preview_js' );

/**
 * Returns CSS for the color schemes.
 *
 * @since Karen 0.1.0
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function karen_get_color_scheme_css( $colors ) {
	$colors = wp_parse_args( $colors, array(
		'base_background_color'         => '',
		'link_color'                    => '',
		'main_text_color'               => '',
		'secondary_text_color'          => '',
		'border_color'                  => '',
		'content_background_color'      => '',
		'content_link_color'            => '',
		'content_main_text_color'       => '',
		'content_secondary_text_color'  => '',
	) );

	return <<<CSS
	/* Color Scheme */

	/* Base Background Color */
	body,
	body.custom-background,
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="tel"],
	input[type="number"],
	textarea,
	.widget-title span {
		background-color: {$colors['base_background_color']};
	}

	mark,
	ins,
	button,
	button[disabled]:hover,
	button[disabled]:focus,
	input[type="button"],
	input[type="button"][disabled]:hover,
	input[type="button"][disabled]:focus,
	input[type="reset"],
	input[type="reset"][disabled]:hover,
	input[type="reset"][disabled]:focus,
	input[type="submit"],
	input[type="submit"][disabled]:hover,
	input[type="submit"][disabled]:focus,
	.menu-toggle.toggled-on,
	.menu-toggle.toggled-on:hover,
	.menu-toggle.toggled-on:focus,
	.site-search .search-field,
	.site-search .search-field:focus,
	.site-search .search-form::after {
		color: {$colors['base_background_color']};
	}

	/* Base Link Color */
	.menu-toggle:hover,
	.menu-toggle:focus,
	a,
	.main-navigation a:hover,
	.main-navigation a:focus,
	.dropdown-toggle:hover,
	.dropdown-toggle:focus,
	.social-navigation a:hover:before,
	.social-navigation a:focus:before,
	.site-branding .site-title a:hover,
	.site-branding .site-title a:focus,
	.site-info a:hover,
	.site-info a:focus {
		color: {$colors['link_color']};
	}

	mark,
	ins,
	button:hover,
	button:focus,
	input[type="button"]:hover,
	input[type="button"]:focus,
	input[type="reset"]:hover,
	input[type="reset"]:focus,
	input[type="submit"]:hover,
	input[type="submit"]:focus {
		background-color: {$colors['link_color']};
	}

	.menu-toggle:hover,
	.menu-toggle:focus {
		border-color: {$colors['link_color']};
	}

	/* Base Main Text Color */
	body,
	blockquote cite,
	blockquote small,
	input[type="text"]:focus,
	input[type="email"]:focus,
	input[type="url"]:focus,
	input[type="password"]:focus,
	input[type="search"]:focus,
	textarea:focus,
	.main-navigation a,
	.menu-toggle,
	.dropdown-toggle,
	.social-navigation a,
	.site-branding .site-title a,
	.site-footer .site-title a,
	.search-submit,
	.site-search .search-toggle {
		color: {$colors['main_text_color']};
	}

	blockquote,
	.menu-toggle.toggled-on,
	.menu-toggle.toggled-on:hover,
	.menu-toggle.toggled-on:focus {
		border-color: {$colors['main_text_color']};
	}

	button,
	button[disabled]:hover,
	button[disabled]:focus,
	input[type="button"],
	input[type="button"][disabled]:hover,
	input[type="button"][disabled]:focus,
	input[type="reset"],
	input[type="reset"][disabled]:hover,
	input[type="reset"][disabled]:focus,
	input[type="submit"],
	input[type="submit"][disabled]:hover,
	input[type="submit"][disabled]:focus,
	.menu-toggle.toggled-on,
	.menu-toggle.toggled-on:hover,
	.menu-toggle.toggled-on:focus {
		background-color: {$colors['main_text_color']};
	}

	/* Border Color */
	fieldset,
	pre,
	abbr,
	acronym,
	table,
	th,
	td,
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	textarea,
	.main-navigation,
	.main-navigation li,
	.main-navigation .primary-menu,
	.menu-toggle,
	.dropdown-toggle:after,
	.social-navigation a,
	.search-submit {
		border-color: {$colors['main_text_color']}; /* Fallback for IE7 and IE8 */
		border-color: {$colors['border_color']};
	}

	hr,
	code,
	.widget-title::before {
		background-color: {$colors['main_text_color']}; /* Fallback for IE7 and IE8 */
		background-color: {$colors['border_color']};
	}

	@media screen and (min-width: 56.875em) {
		.main-navigation .primary-menu > li a {
			/*background-image: repeating-linear-gradient(45deg, transparent, transparent 1px, {$colors['border_color']} 1px, {$colors['border_color']} 4px);*/
		}

		.main-navigation ul ul {
			background-color: {$colors['base_background_color']};
		}

		.main-navigation ul ul,
		.main-navigation ul ul li {
			border-color: {$colors['base_background_color']};
		}

	}

	/* Base Secondary Text Color */
	blockquote,
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	textarea,
	.site-description,
	.site-info,
	.site-info a,
	.widget_recent_entries .post-date,
	.widget-recent-posts .post-date,
	.widget_recent_entries .post-date a,
	.widget-recent-posts .post-date a,
	.widget-twitter .tweet-meta,
	.widget-twitter .tweet-meta a {
		color: {$colors['secondary_text_color']};
	}

	.widget_calendar tbody a:hover,
	.widget_calendar tbody a:focus,
	.jetpack_subscription_widget form:before,
	.widget_mailchimpsf_widget #mc_signup:before {
		background-color: {$colors['secondary_text_color']};
	}

	/* Content Background Color */
	.site-content,
	.site-content input[type="text"],
	.site-content input[type="email"],
	.site-content input[type="url"],
	.site-content input[type="password"],
	.site-content input[type="search"],
	.site-content textarea,
	.blog .hentry.display-featured .entry-title,
	.archive .hentry.display-featured .entry-title,
	.site-content .widget-title span {
		background-color: {$colors['content_background_color']};
	}

	.site-content mark,
	.site-content ins,
	.site-content button,
	.site-content button[disabled]:hover,
	.site-content button[disabled]:focus,
	.site-content input[type="button"],
	.site-content input[type="button"][disabled]:hover,
	.site-content input[type="button"][disabled]:focus,
	.site-content input[type="reset"],
	.site-content input[type="reset"][disabled]:hover,
	.site-content input[type="reset"][disabled]:focus,
	.site-content input[type="submit"],
	.site-content input[type="submit"][disabled]:hover,
	.site-content input[type="submit"][disabled]:focus,
	.site-content .widget_calendar tbody a,
	.site-content .widget_calendar tbody a:hover,
	.site-content .widget_calendar tbody a:focus,
	.site-content .page-links a,
	.site-content .page-links a:hover,
	.site-content .page-links a:focus {
		color: {$colors['content_background_color']};
	}

	@media screen and (min-width: 56.875em) {
		.main-navigation ul ul li {
			background-color: {$colors['content_background_color']};
		}
	}

	/* Content Link Color */
	.site-content a,
	.site-content .post-navigation a:hover .post-title,
	.site-content .post-navigation a:focus .post-title,
	.site-content .tagcloud a:hover,
	.site-content .tagcloud a:focus,
	.site-content .entry-title a:hover,
	.site-content .entry-title a:focus,
	.site-content .entry-footer a:hover,
	.site-content .entry-footer a:focus,
	.site-content .comment-metadata a:hover,
	.site-content .comment-metadata a:focus,
	.pingback .comment-edit-link:hover,
	.pingback .comment-edit-link:focus,
	.comment-reply-link,
	.comment-reply-link:hover,
	.comment-reply-link:focus,
	.required {
		color: {$colors['content_link_color']};
	}

	.site-content mark,
	.site-content ins,
	.site-content button:hover,
	.site-content button:focus,
	.site-content input[type="button"]:hover,
	.site-content input[type="button"]:focus,
	.site-content input[type="reset"]:hover,
	.site-content input[type="reset"]:focus,
	.site-content input[type="submit"]:hover,
	.site-content input[type="submit"]:focus,
	.site-content .widget_calendar tbody a,
	.page-links a:hover,
	.page-links a:focus {
		background-color: {$colors['content_link_color']};
	}

	.site-content .tagcloud a:hover,
	.site-content .tagcloud a:focus {
		border-color: {$colors['content_link_color']};
	}

	/* Content Main Text Color */
	.site-content,
	.site-content blockquote cite,
	.site-content blockquote small,
	.site-content input[type="text"]:focus,
	.site-content input[type="email"]:focus,
	.site-content input[type="url"]:focus,
	.site-content input[type="password"]:focus,
	.site-content input[type="search"]:focus,
	.site-content textarea:focus,
	.site-content .post-navigation a,
	.site-content .pagination a:hover,
	.site-content .pagination a:focus,
	.site-content .widget-title a,
	.site-content .entry-title a,
	.page-links > .page-links-title,
	.comment-author,
	.site-content .comment-reply-title small a:hover,
	.site-content .comment-reply-title small a:focus,
	.site-content .search-submit {
		color: {$colors['content_main_text_color']};
	}

	.site-content blockquote {
		border-color: {$colors['content_main_text_color']};
	}

	.site-content button,
	.site-content button[disabled]:hover,
	.site-content button[disabled]:focus,
	.site-content input[type="button"],
	.site-content input[type="button"][disabled]:hover,
	.site-content input[type="button"][disabled]:focus,
	.site-content input[type="reset"],
	.site-content input[type="reset"][disabled]:hover,
	.site-content input[type="reset"][disabled]:focus,
	.site-content input[type="submit"],
	.site-content input[type="submit"][disabled]:hover,
	.site-content input[type="submit"][disabled]:focus,
	.pagination:before,
	.pagination:after,
	.page-links a {
		background-color: {$colors['content_main_text_color']};
	}

	@media screen and (min-width: 56.875em) {
		.main-navigation ul ul a {
			color: {$colors['content_main_text_color']};
		}

		.main-navigation ul ul a:hover {
			color: {$colors['content_link_color']};
		}
	}

	/* Content Secondary Text Color */


	.site-content blockquote,
	.site-content input[type="text"],
	.site-content input[type="email"],
	.site-content input[type="url"],
	.site-content input[type="password"],
	.site-content input[type="search"],
	.site-content textarea,
	.post-password-form label,
	.site-content a:hover,
	.site-content a:focus,
	.site-content a:active,
	.post-navigation .meta-nav,
	.image-navigation,
	.comment-navigation,
	.site-content .widget_recent_entries .post-date,
	.site-content .widget-recent-posts .post-date,
	.site-content .widget_recent_entries .post-date a,
	.site-content .widget-recent-posts .post-date a,
	.widget_rss .rss-date,
	.widget_rss cite,
	.entry-footer,
	.site-content .entry-footer a,
	.sticky-post,
	.taxonomy-description,
	.entry-caption,
	.comment-metadata,
	.pingback .edit-link,
	.comment-metadata a,
	.pingback .comment-edit-link,
	.comment-form label,
	.comment-notes,
	.comment-awaiting-moderation,
	.logged-in-as,
	.form-allowed-tags,
	.wp-caption .wp-caption-text,
	.gallery-caption,
	.widecolumn label,
	.widecolumn .mu_register label,
	.site-content .widget .widget-title:before,
	.site-content .widget-twitter .tweet-meta,
	.site-content .widget-twitter .tweet-meta a {
		color: {$colors['content_secondary_text_color']};
	}

	.widget_calendar tbody a:hover,
	.widget_calendar tbody a:focus,
	.blog .site-main > article.display-overlay.no-thumbnail:before,
	.archive .site-main > article.display-overlay.no-thumbnail:before,
	.site-content .jetpack_subscription_widget form:before,
	.site-content .widget_mailchimpsf_widget #mc_signup:before {
		background-color: {$colors['content_secondary_text_color']};
	}

	/* Content Border Color */
	.site-content fieldset,
	.site-content pre,
	.site-content abbr,
	.site-content acronym,
	.site-content table,
	.site-content th,
	.site-content td,
	.site-content input[type="text"],
	.site-content input[type="email"],
	.site-content input[type="url"],
	.site-content input[type="password"],
	.site-content input[type="search"],
	.site-content textarea,
	.image-navigation,
	.comment-navigation,
	.tagcloud a,
	.entry-content,
	.entry-summary,
	.page-links a,
	.page-links > span,
	.comment-list article,
	.comment-list .pingback,
	.comment-list .trackback,
	.comment-reply-link,
	.no-comments,
	.widecolumn .mu_register .mu_alert,
	.site-content .search-submit,
	.site-content .social-share > div,
	.site-content .social-share button,
	.site-breadcrumbs,
	.post-navigation,
	.post-navigation div + div,
	.pagination,
	.widget,
	.page-header,
	.page-links a,
	.comments-title,
	.comment-reply-title {
		border-color: {$colors['content_main_text_color']}; /* Fallback for IE7 and IE8 */
		border-color: {$colors['content_border_color']};
	}

	.site-content hr,
	.site-content code,
	.site-content .widget-title::before {
		background-color: {$colors['content_main_text_color']}; /* Fallback for IE7 and IE8 */
		background-color: {$colors['content_border_color']};
	}

	@media screen and (min-width: 56.875em) {
		.main-navigation ul ul li,
		.main-navigation ul ul {
			border-color: {$colors['content_main_text_color']};
			border-color: {$colors['content_border_color']};
		}
	}


CSS;
}


/**
 * Outputs an Underscore template for generating CSS for the color scheme.
 *
 * The template generates the css dynamically for instant display in the
 * Customizer preview.
 *
 * @since Karen 0.1.0
 */
function karen_color_scheme_css_template() {
	$colors = array(
		'base_background_color'         => '{{ data.base_background_color }}',
		'link_color'                    => '{{ data.link_color }}',
		'main_text_color'               => '{{ data.main_text_color }}',
		'secondary_text_color'          => '{{ data.secondary_text_color }}',
		'border_color'                  => '{{ data.border_color }}',
		'content_background_color'      => '{{ data.content_background_color }}',
		'content_link_color'            => '{{ data.content_link_color }}',
		'content_main_text_color'       => '{{ data.content_main_text_color }}',
		'content_secondary_text_color'  => '{{ data.content_secondary_text_color }}',
		'content_border_color'          => '{{ data.content_border_color }}',
	);
	?>
	<script type="text/html" id="tmpl-karen-color-scheme">
		<?php echo wp_strip_all_tags( karen_get_color_scheme_css( $colors ) ); ?>
	</script>
	<?php
}
add_action( 'customize_controls_print_footer_scripts', 'karen_color_scheme_css_template' );



/**
 * Enqueues front-end CSS for the base background color.
 *
 * @since Karen 0.1.0
 *
 * @see wp_add_inline_style()
 */
function karen_base_background_color_css() {
	$color_scheme          = karen_get_color_schemes();
	$default_color         = $color_scheme['default']['colors'][0];
	$base_background_color = get_theme_mod( 'base_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $base_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Custom Background Color */

		body,
		body.custom-background,
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		textarea,
		.widget-title span {
			background-color: %1$s;
		}

		mark,
		ins,
		button,
		button[disabled]:hover,
		button[disabled]:focus,
		input[type="button"],
		input[type="button"][disabled]:hover,
		input[type="button"][disabled]:focus,
		input[type="reset"],
		input[type="reset"][disabled]:hover,
		input[type="reset"][disabled]:focus,
		input[type="submit"],
		input[type="submit"][disabled]:hover,
		input[type="submit"][disabled]:focus,
		.menu-toggle.toggled-on,
		.menu-toggle.toggled-on:hover,
		.menu-toggle.toggled-on:focus,
		.site-search .search-field,
		.site-search .search-field:focus,
		.site-search .search-form::after {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'karen-style', sprintf( $css, esc_attr( $base_background_color ) ) );
}
add_action( 'wp_enqueue_scripts', 'karen_base_background_color_css', 11 );

/**
 * Enqueues front-end CSS for the base link color.
 *
 * @since Karen 0.1.0
 *
 * @see wp_add_inline_style()
 */
function karen_base_link_color_css() {
	$color_scheme    = karen_get_color_schemes();
	$default_color   = $color_scheme['default']['colors'][1];
	$link_color = get_theme_mod( 'link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $link_color === $default_color ) {
		return;
	}

	$css = '
		/* Custom Link Color */
		.menu-toggle:hover,
		.menu-toggle:focus,
		a,
		.main-navigation a:hover,
		.main-navigation a:focus,
		.dropdown-toggle:hover,
		.dropdown-toggle:focus,
		.social-navigation a:hover:before,
		.social-navigation a:focus:before,
		.site-branding .site-title a:hover,
		.site-branding .site-title a:focus,
		.site-info a:hover,
		.site-info a:focus {
			color: %1$s;
		}

		mark,
		ins,
		button:hover,
		button:focus,
		input[type="button"]:hover,
		input[type="button"]:focus,
		input[type="reset"]:hover,
		input[type="reset"]:focus,
		input[type="submit"]:hover,
		input[type="submit"]:focus {
			background-color: %1$s;
		}

		.menu-toggle:hover,
		.menu-toggle:focus {
			border-color: %1$s;
		}

		@media screen and (min-width: 56.875em) {
			.main-navigation li:hover > a,
			.main-navigation li.focus > a {
				color: %1$s;
			}
		}
	';

	wp_add_inline_style( 'karen-style', sprintf( $css , esc_attr( $link_color ) ) );
}
add_action( 'wp_enqueue_scripts', 'karen_base_link_color_css', 11 );

/**
 * Enqueues front-end CSS for the base main text color.
 *
 * @since Karen 0.1.0
 *
 * @see wp_add_inline_style()
 */
function karen_base_main_text_color_css() {
	$color_scheme    = karen_get_color_schemes();
	$default_color   = $color_scheme['default']['colors'][2];
	$main_text_color = get_theme_mod( 'main_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $main_text_color === $default_color ) {
		return;
	}

	// Convert main text hex color to rgba.
	$main_text_color_rgb = karen_hex2rgb( $main_text_color );

	// If the rgba values are empty return early.
	if ( empty( $main_text_color_rgb ) ) {
		return;
	}

	// If we get this far, we have a custom color scheme.
	$border_color = vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.2)', $main_text_color_rgb );

	$css = '
		/* Custom Main Text Color */
		body,
		blockquote cite,
		blockquote small,
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="url"]:focus,
		input[type="password"]:focus,
		input[type="search"]:focus,
		textarea:focus,
		.main-navigation a,
		.menu-toggle,
		.dropdown-toggle,
		.social-navigation a,
		.site-branding .site-title a,
		.site-footer .site-title a,
		.search-submit,
		.site-search .search-toggle {
			color: %1$s;
		}

		blockquote,
		.menu-toggle.toggled-on,
		.menu-toggle.toggled-on:hover,
		.menu-toggle.toggled-on:focus {
			border-color: %1$s;
		}

		button,
		button[disabled]:hover,
		button[disabled]:focus,
		input[type="button"],
		input[type="button"][disabled]:hover,
		input[type="button"][disabled]:focus,
		input[type="reset"],
		input[type="reset"][disabled]:hover,
		input[type="reset"][disabled]:focus,
		input[type="submit"],
		input[type="submit"][disabled]:hover,
		input[type="submit"][disabled]:focus,
		.menu-toggle.toggled-on,
		.menu-toggle.toggled-on:hover,
		.menu-toggle.toggled-on:focus {
			background-color: %1$s;
		}

		/* Border Color */
		fieldset,
		pre,
		abbr,
		acronym,
		table,
		th,
		td,
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		textarea,
		.main-navigation,
		.main-navigation li,
		.main-navigation .primary-menu,
		.menu-toggle,
		.dropdown-toggle:after,
		.social-navigation a,
		.search-submit {
			border-color: %1$s; 
			border-color: %2$s;
		}

		hr,
		code,
		.widget-title::before {
			background-color: %1$s;
			background-color: %2$s;
		}

		@media screen and (min-width: 56.875em) {
			/* .main-navigation ul ul,
			.main-navigation ul ul li {
				border-color: %2$s;
			}

			.main-navigation ul ul:before {
				border-top-color: %2$s;
				border-bottom-color: %2$s;
			}

			.main-navigation .primary-menu > li a {
				background-image: repeating-linear-gradient(45deg, transparent, transparent 1px, %2$s 1px, %2$s 4px);
			} */

		}
	';

	wp_add_inline_style( 'karen-style', sprintf( $css, esc_attr( $main_text_color ), esc_attr( $border_color ) ) );
}
add_action( 'wp_enqueue_scripts', 'karen_base_main_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the base secondary text color.
 *
 * @since Karen 0.1.0
 *
 * @see wp_add_inline_style()
 */
function karen_base_secondary_text_color_css() {
	$color_scheme    = karen_get_color_schemes();
	$default_color   = $color_scheme['default']['colors'][3];
	$secondary_text_color = get_theme_mod( 'secondary_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Custom Secondary Text Color */
		blockquote,
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		textarea,
		.site-description,
		.site-info,
		.site-info a,
		.widget_recent_entries .post-date,
		.widget-recent-posts .post-date,
		.widget_recent_entries .post-date a,
		.widget-recent-posts .post-date a,
		.widget-twitter .tweet-meta,
		.widget-twitter .tweet-meta a{
			color: %1$s;
		}

		.widget_calendar tbody a:hover,
		.widget_calendar tbody a:focus,
		.jetpack_subscription_widget form:before,
		.widget_mailchimpsf_widget #mc_signup:before {
			background-color: %1$s;
		}

	';

	wp_add_inline_style( 'karen-style', sprintf( $css, esc_attr( $secondary_text_color ) ) );
}
add_action( 'wp_enqueue_scripts', 'karen_base_secondary_text_color_css', 11 );



/**
 * Enqueues front-end CSS for the page background color.
 *
 * @since Karen 0.1.0
 *
 * @see wp_add_inline_style()
 */
function karen_content_background_color_css() {
	$color_scheme          = karen_get_color_schemes();
	$default_color         = $color_scheme['default']['colors'][4];
	$content_background_color = get_theme_mod( 'content_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $content_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Custom Page Background Color */
		.site-content,
		.site-content input[type="text"],
		.site-content input[type="email"],
		.site-content input[type="url"],
		.site-content input[type="password"],
		.site-content input[type="search"],
		.site-content textarea,
		.blog .hentry.display-featured .entry-title,
		.archive .hentry.display-featured .entry-title,
		.site-content .widget-title span {
			background-color: %1$s;
		}

		.site-content mark,
		.site-content ins,
		.site-content button,
		.site-content button[disabled]:hover,
		.site-content button[disabled]:focus,
		.site-content input[type="button"],
		.site-content input[type="button"][disabled]:hover,
		.site-content input[type="button"][disabled]:focus,
		.site-content input[type="reset"],
		.site-content input[type="reset"][disabled]:hover,
		.site-content input[type="reset"][disabled]:focus,
		.site-content input[type="submit"],
		.site-content input[type="submit"][disabled]:hover,
		.site-content input[type="submit"][disabled]:focus,
		.site-content .widget_calendar tbody a,
		.site-content .widget_calendar tbody a:hover,
		.site-content .widget_calendar tbody a:focus,
		.page-links a,
		.page-links a:hover,
		.page-links a:focus {
			color: %1$s;
		}

		@media screen and (min-width: 56.875em) {
			.main-navigation ul ul li {
				background-color: %1$s;
			}
		}


	';

	wp_add_inline_style( 'karen-style', sprintf( $css, esc_attr( $content_background_color ) ) );
}
add_action( 'wp_enqueue_scripts', 'karen_content_background_color_css', 11 );

/**
 * Enqueues front-end CSS for the content link color.
 *
 * @since Karen 0.1.0
 *
 * @see wp_add_inline_style()
 */
function karen_content_link_color_css() {
	$color_scheme    = karen_get_color_schemes();
	$default_color   = $color_scheme['default']['colors'][5];
	$content_link_color = get_theme_mod( 'content_link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $content_link_color === $default_color ) {
		return;
	}

	$css = '
		/* Content Custom Link Color */
		.site-content a,
		.post-navigation a:hover .post-title,
		.post-navigation a:focus .post-title,
		.site-content .tagcloud a:hover,
		.site-content .tagcloud a:focus,
		.site-content .entry-title a:hover,
		.site-content .entry-title a:focus,
		.site-content .entry-footer a:hover,
		.site-content .entry-footer a:focus,
		.comment-metadata a:hover,
		.comment-metadata a:focus,
		.pingback .comment-edit-link:hover,
		.pingback .comment-edit-link:focus,
		.comment-reply-link,
		.comment-reply-link:hover,
		.comment-reply-link:focus,
		.required {
			color: %1$s;
		}

		.site-content mark,
		.site-content ins,
		.site-content button:hover,
		.site-content button:focus,
		.site-content input[type="button"]:hover,
		.site-content input[type="button"]:focus,
		.site-content input[type="reset"]:hover,
		.site-content input[type="reset"]:focus,
		.site-content input[type="submit"]:hover,
		.site-content input[type="submit"]:focus,
		.site-content .widget_calendar tbody a,
		.page-links a:hover,
		.page-links a:focus {
			background-color: %1$s;
		}

		.site-content .tagcloud a:hover,
		.site-content .tagcloud a:focus {
			border-color: %1$s;
		}

		@media screen and (min-width: 56.875em) {
			.main-navigation ul ul a:hover {
				color: %1$s;
			}
		}
	';

	wp_add_inline_style( 'karen-style', sprintf( $css, esc_attr( $content_link_color ) ) );
}
add_action( 'wp_enqueue_scripts', 'karen_content_link_color_css', 11 );

/**
 * Enqueues front-end CSS for the content main text color.
 *
 * @since Karen 0.1.0
 *
 * @see wp_add_inline_style()
 */
function karen_content_main_text_color_css() {
	$color_scheme    = karen_get_color_schemes();
	$default_color   = $color_scheme['default']['colors'][6];
	$content_main_text_color = get_theme_mod( 'content_main_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $content_main_text_color === $default_color ) {
		return;
	}

	// Convert main text hex color to rgba.
	$content_main_text_color_rgb = karen_hex2rgb( $content_main_text_color );

	// If the rgba values are empty return early.
	if ( empty( $content_main_text_color_rgb ) ) {
		return;
	}

	// If we get this far, we have a custom color scheme.
	$content_border_color = vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.2)', $content_main_text_color_rgb );

	$css = '
		/* Custom Main Text Color */
		.site-content,
		.site-content blockquote cite,
		.site-content blockquote small,
		.site-content input[type="text"]:focus,
		.site-content input[type="email"]:focus,
		.site-content input[type="url"]:focus,
		.site-content input[type="password"]:focus,
		.site-content input[type="search"]:focus,
		.site-content textarea:focus,
		.site-content .post-navigation a,
		.site-content .pagination a:hover,
		.site-content .pagination a:focus,
		.site-content .widget-title a,
		.site-content .entry-title a,
		.page-links > .page-links-title,
		.comment-author,
		.site-content .comment-reply-title small a:hover,
		.site-content .comment-reply-title small a:focus,
		.site-content .search-submit {
			color: %1$s
		}

		.site-content blockquote {
			border-color: %1$s;
		}

		.site-content button,
		.site-content button[disabled]:hover,
		.site-content button[disabled]:focus,
		.site-content input[type="button"],
		.site-content input[type="button"][disabled]:hover,
		.site-content input[type="button"][disabled]:focus,
		.site-content input[type="reset"],
		.site-content input[type="reset"][disabled]:hover,
		.site-content input[type="reset"][disabled]:focus,
		.site-content input[type="submit"],
		.site-content input[type="submit"][disabled]:hover,
		.site-content input[type="submit"][disabled]:focus,
		.pagination:before,
		.pagination:after,
		.site-content .page-links a {
			background-color: %1$s;
		}

		/* Border Color */
		.site-content fieldset,
		.site-content pre,
		.site-content abbr,
		.site-content acronym,
		.site-content table,
		.site-content th,
		.site-content td,
		.site-content input[type="text"],
		.site-content input[type="email"],
		.site-content input[type="url"],
		.site-content input[type="password"],
		.site-content input[type="search"],
		.site-content textarea,
		.image-navigation,
		.comment-navigation,
		.site-content .tagcloud a,
		.entry-content,
		.entry-summary,
		.page-links a,
		.page-links > span,
		.comment-list article,
		.comment-list .pingback,
		.comment-list .trackback,
		.comment-reply-link,
		.no-comments,
		.widecolumn .mu_register .mu_alert,
		.site-content .search-submit,
		.site-content .social-share > div,
		.site-content .social-share button,
		.site-breadcrumbs,
		.post-navigation,
		.post-navigation div + div,
		.pagination,
		.site-content .widget,
		.page-header,
		.site-content .page-links a,
		.comments-title,
		.comment-reply-title {
			border-color: %1$s; /* Fallback for IE7 and IE8 */
			border-color: %2$s;
		}

		.site-content hr,
		.site-content code,
		.site-content .widget-title::before {
			background-color: %1$s; /* Fallback for IE7 and IE8 */
			background-color: %2$s;
		}

		@media screen and (min-width: 56.875em) {
			.main-navigation ul ul,
			.main-navigation ul ul li {
				border-color: %1$s; /* Fallback for IE7 and IE8 */
				border-color: %2$s;
			}

			.main-navigation ul ul a {
				color: %1$s;
			}
		}


	';

	wp_add_inline_style( 'karen-style', sprintf( $css, esc_attr( $content_main_text_color ),  esc_attr( $content_border_color ) ) );
}
add_action( 'wp_enqueue_scripts', 'karen_content_main_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the content secondary text color.
 *
 * @since Karen 0.1.0
 *
 * @see wp_add_inline_style()
 */
function karen_content_secondary_text_color_css() {
	$color_scheme    = karen_get_color_schemes();
	$default_color   = $color_scheme['default']['colors'][7];
	$content_secondary_text_color = get_theme_mod( 'content_secondary_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $content_secondary_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Custom Secondary Text Color */


		.site-content blockquote,
		.site-content input[type="text"],
		.site-content input[type="email"],
		.site-content input[type="url"],
		.site-content input[type="password"],
		.site-content input[type="search"],
		.site-content textarea,
		.post-password-form label,
		.site-content a:hover,
		.site-content a:focus,
		.site-content a:active,
		.post-navigation .meta-nav,
		.image-navigation,
		.comment-navigation,
		.site-content .widget_recent_entries .post-date,
		.site-content .widget-recent-posts .post-date,
		.site-content .widget_recent_entries .post-date a,
		.site-content .widget-recent-posts .post-date a,
		.site-content .widget_rss .rss-date,
		.site-content .widget_rss cite,
		.entry-footer,
		.site-content .entry-footer a,
		.sticky-post,
		.taxonomy-description,
		.entry-caption,
		.comment-metadata,
		.pingback .edit-link,
		.site-content .comment-metadata a,
		.pingback .comment-edit-link,
		.comment-form label,
		.comment-notes,
		.comment-awaiting-moderation,
		.logged-in-as,
		.form-allowed-tags,
		.wp-caption .wp-caption-text,
		.gallery-caption,
		.widecolumn label,
		.widecolumn .mu_register label,
		.site-content .widget .widget-title:before,
		.site-content .widget-twitter .tweet-meta,
		.site-content .widget-twitter .tweet-meta a {
			color: %1$s;
		}

		.site-content .widget_calendar tbody a:hover,
		.site-content .widget_calendar tbody a:focus,
		.blog .site-main > article.display-overlay.no-thumbnail:before,
		.archive .site-main > article.display-overlay.no-thumbnail:before,
		.site-content .jetpack_subscription_widget form:before,
		.site-content .widget_mailchimpsf_widget #mc_signup:before {
			background-color: %1$s;
		}
	';

	wp_add_inline_style( 'karen-style', sprintf( $css , esc_attr( $content_secondary_text_color ) ) );
}
add_action( 'wp_enqueue_scripts', 'karen_content_secondary_text_color_css', 11 );
