<?php
/**
 * Custom Karen template tags
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * 
 * @package Karen
 * @since Karen 0.1.0
 */

if ( ! function_exists( 'karen_entry_meta' ) ) :
/**
 * Prints HTML with meta information for the categories, tags.
 *
 * Create your own karen_entry_meta() function to override in a child theme.
 *
 * @since Karen 0.1.0
 */
function karen_entry_meta() {
	if ( 'post' === get_post_type() ) {
		$author_avatar_size = apply_filters( 'karen_author_avatar_size', 49 );
		printf( '<span class="byline"><span class="author vcard">%1$s<span class="screen-reader-text">%2$s </span> <a class="url fn n" href="%3$s">%4$s</a></span></span>',
			get_avatar( get_the_author_meta( 'user_email' ), $author_avatar_size ),
			_x( 'Author', 'Used before post author name.', 'karen' ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			get_the_author()
		);
	}

	if ( 'post' === get_post_type() ) {
		karen_entry_categories();
	}

	if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
		karen_entry_date();
	}

	$format = get_post_format();
	if ( current_theme_supports( 'post-formats', $format ) ) {
		printf( '<span class="entry-format">%1$s<a href="%2$s">%3$s</a></span>',
			sprintf( '<span class="screen-reader-text">%s </span>', _x( 'Format', 'Used before post format.', 'karen' ) ),
			esc_url( get_post_format_link( $format ) ),
			get_post_format_string( $format )
		);
	}
}
endif;

if ( ! function_exists( 'karen_entry_date' ) ) :
/**
 * Prints HTML with date information for current post.
 *
 * Create your own karen_entry_date() function to override in a child theme.
 *
 * @since Karen 0.1.0
 */
function karen_entry_date() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		get_the_date(),
		esc_attr( get_the_modified_date( 'c' ) ),
		get_the_modified_date()
	);

	printf( '<span class="posted-on"><span class="screen-reader-text">%1$s </span><a href="%2$s" rel="bookmark">%3$s</a></span>',
		_x( 'Posted on', 'Used before publish date.', 'karen' ),
		esc_url( get_permalink() ),
		$time_string
	);
}
endif;

if ( ! function_exists( 'karen_entry_taxonomies' ) ) :
/**
 * Prints HTML with category and tags for current post.
 *
 * Create your own karen_entry_taxonomies() function to override in a child theme.
 *
 * @since Karen 0.1.0
 */
function karen_entry_taxonomies() {
	$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'karen' ) );
	if ( $categories_list && karen_categorized_blog() ) {
		printf( '<span class="cat-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
			_x( 'Categories', 'Used before category names.', 'karen' ),
			$categories_list
		);
	}

	$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'karen' ) );
	if ( $tags_list ) {
		printf( '<span class="tags-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
			_x( 'Tags', 'Used before tag names.', 'karen' ),
			$tags_list
		);
	}
}
endif;

if ( ! function_exists( 'karen_entry_categories' ) ) :
/**
 * Prints HTML with category for current post.
 *
 * Create your own karen_entry_categories() function to override in a child theme.
 *
 * @since Karen 0.1.0
 */
function karen_entry_categories() {

	$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'karen' ) );
	if ( $categories_list && karen_categorized_blog() ) {
		printf( '<span class="cat-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
			_x( 'Categories', 'Used before category names.', 'karen' ),
			$categories_list
		);
	}

}
endif;

if ( ! function_exists( 'karen_entry_tags' ) ) :
/**
 * Prints HTML with tags for current post.
 *
 * Create your own karen_entry_tags() function to override in a child theme.
 *
 * @since Karen 0.1.0
 */
function karen_entry_tags() {

	$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'karen' ) );
	if ( $tags_list ) {
		printf( '<span class="tags-links"><span>%1$s </span>%2$s</span>',
			_x( 'Tagged as: ', 'Used before tag names.', 'karen' ),
			$tags_list
		);
	}
}
endif;

if ( ! function_exists( 'karen_post_thumbnail' ) ) :
/**
 * Displays an optional post thumbnail.
 *
 * Wraps the post thumbnail in an anchor element on index views, or a div
 * element when on single views.
 *
 * Create your own karen_post_thumbnail() function to override in a child theme.
 *
 * @since Karen 0.1.0
 */
function karen_post_thumbnail() {
	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
		return;
	}

	if ( is_singular() ) :
	?>

	<div class="post-thumbnail">
		<?php the_post_thumbnail(); ?>
	</div><!-- .post-thumbnail -->

	<?php else : ?>

	<a class="post-thumbnail" href="<?php the_permalink(); ?>">
		<?php the_post_thumbnail( 'post-thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
	</a>

	<?php endif; // End is_singular()
}
endif;

if ( ! function_exists( 'karen_excerpt' ) ) :
	/**
	 * Displays the optional excerpt.
	 *
	 * Wraps the excerpt in a div element.
	 *
	 * Create your own karen_excerpt() function to override in a child theme.
	 *
	 * @since Karen 0.1.0
	 *
	 * @param string $class Optional. Class string of the div element. Defaults to 'entry-summary'.
	 */
	function karen_excerpt( $class = 'entry-summary' ) {
		$class = esc_attr( $class );

		if ( has_excerpt() || is_search() ) : ?>
			<div class="<?php echo $class; ?>">
				<?php the_excerpt(); ?>
			</div><!-- .<?php echo $class; ?> -->
		<?php endif;
	}
endif;

if ( ! function_exists( 'karen_excerpt_more' ) && ! is_admin() ) :
/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a 'Continue reading' link.
 *
 * Create your own karen_excerpt_more() function to override in a child theme.
 *
 * @since Karen 0.1.0
 *
 * @return string 'Continue reading' link prepended with an ellipsis.
 */
function karen_excerpt_more() {
	$link = sprintf( '<a href="%1$s" class="more-link">%2$s</a>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'karen' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'karen_excerpt_more' );
endif;

/**
 * Determines whether blog/site has more than one category.
 *
 * Create your own karen_categorized_blog() function to override in a child theme.
 *
 * @since Karen 0.1.0
 *
 * @return bool True if there is more than one category, false otherwise.
 */
function karen_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'karen_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'karen_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so karen_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so karen_categorized_blog should return false.
		return false;
	}
}

if ( ! function_exists( 'karen_breadcrumbs' ) ) :
/**
 * Breadcrumbs
 *
 * @since Karen 0.1.0
 */
function karen_breadcrumbs() { 
	if ( ! is_front_page() ) {
		printf( '<div class="site-breadcrumbs" role="navigation" aria-label="%1$s" ><a href="%2$s">%3$s</a>',
			esc_attr__('Breadcrumb Navigation', 'karen'),
			esc_url( home_url() ),
			__('Home', 'karen')
		);
	}

	if ( (is_category() || is_single()) && !is_attachment() ) {
		$category = get_the_category();
		if (count($category) > 0){
			$ID = $category[0]->cat_ID;
			if ( $ID ) {
				echo get_category_parents($ID, TRUE, ' ', FALSE );
			}
		}
	}

	if(is_single() || is_page()) {
		if ( !is_front_page() ){
			echo '<span>';
			the_title();
			echo '</span>';
		}
	}
	if(is_tag()){ echo __('Tag: ', 'karen') . single_tag_title('',FALSE); }
	if(is_404()){ echo __('404 - Page not Found', 'karen') ; }
	if(is_search()){ echo __('Search', 'karen'); }
	if(is_year()){ echo get_the_time(_x( 'Y', 'yearly archives date format', 'karen' ) ); }
	if(is_month()){ echo get_the_time( _x( 'F Y', 'monthly archives date format', 'karen' ) ); }
	if (is_author()){ echo __('Posts by ', 'karen') . get_the_author(); }

	if ( !is_front_page() ) {
		echo "</div>";	
	}
}

endif;

/**
 * Get related posts by tags
 * 
 * @since Karen 0.1.0
 */
function karen_related_posts() {

	$current_id = get_the_ID();
	$tags = wp_get_post_tags( $current_id, array( 'fields' => 'ids' ) );
	//print_r($current_id);
	$query = array (
			'posts__not_in' => array ( $current_id ),
			'tag__in' => $tags,
			'posts_per_page' => 4,
		);

	$result = new WP_Query( $query );
	
	if ( $result->have_posts() ) :
	?>
		<div id="related-posts" class="related-posts widget widget-recent-posts">
			<h2 class="related-title widget-title"><span><?php _e('Related Posts', 'karen'); ?></span></h2>
			<ul>
			<?php while ( $result->have_posts() ) : $result->the_post() ?>
				<li>
				<?php if ( has_post_thumbnail() ) : ?>
					<a class="post-thumbnail alignleft" href="<?php the_permalink(); ?>">
						<?php the_post_thumbnail( 'thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
					</a>
				<?php endif; ?>
					<span class="entry-title"><a href="<?php the_permalink(); ?>"><?php get_the_title() ? the_title() : the_ID(); ?></a></span>
					<span class="post-date"><?php echo get_the_date(); ?></span>
				</li>
			<?php endwhile; ?>
			</ul>
		</div>
	<?php
	endif;	
	wp_reset_postdata();
}

/**
 * Get first blockquote from the post content
 * used for quote post format
 * 
 * @since Karen 0.1.0
 */
function karen_get_blockquote() {
	$dom = new DOMDocument;
	$dom->loadHTML( apply_filters( 'the_content', get_the_content( '' ) ) );
	$blockquotes = $dom->getElementsByTagname( 'blockquote' );

	$blockquote = '';

	if ( $blockquotes->length > 0 ) {

		// First blockquote
		$blockquote = $blockquotes->item(0);


		$cite = $blockquote->getElementsByTagName( 'cite' )->item( 0 );
		$p = $blockquote->getElementsByTagName( 'p' );

		$cite_content = '';
		if ( $cite && $p ) {

			// Remove the cite from the paragraph
			foreach ( $p as $paragraph )
				try { $paragraph->removeChild( $cite ); }
				catch( Exception $e ) {}

			$cite_content = $dom->saveXML( $cite );
		}

		$blockquote_content = '';
		foreach ( $p as $paragraph ) {
			if ( strlen( trim( $paragraph->nodeValue ) ) > 0 )
				$blockquote_content .= $dom->saveXML( $paragraph );
			else
				$paragraph->parentNode->removeChild( $paragraph );

		}

		$blockquote->parentNode->removeChild( $blockquote );
		$remaining_content = $dom->saveXML();
	}
	
	if ( isset( $cite_content ) ) 
		$cite_print =  $cite_content ;
	else 
		$cite_print = '';

	$print_content = '';
	if ( isset( $blockquote_content ) ) {
		$print_content = '<blockquote>' . $blockquote_content . $cite_print . '</blockquote>';
	}

	return $print_content;
}


/**
 * Flushes out the transients used in karen_categorized_blog().
 *
 * @since Karen 0.1.0
 */
function karen_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'karen_categories' );
}
add_action( 'edit_category', 'karen_category_transient_flusher' );
add_action( 'save_post',     'karen_category_transient_flusher' );

if ( ! function_exists( 'karen_the_custom_logo' ) ) :
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 * @since Karen 0.1.5
 */
function karen_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}
endif;

